@@ -14,7 +14,7 @@ class ApiKey(AbstractApiClass):
         self.created_at = createdAt
 
     def __repr__(self):
-        return f"ApiKey(api_key_id={repr(self.api_key_id)}, api_key={repr(self.api_key)}, tag={repr(self.tag)}, created_at={repr(self.created_at)})"
+        return f"ApiKey(api_key_id={repr(self.api_key_id)},\n  api_key={repr(self.api_key)},\n  tag={repr(self.tag)},\n  created_at={repr(self.created_at)})"
 
     def to_dict(self):
         return {'api_key_id': self.api_key_id, 'api_key': self.api_key, 'tag': self.tag, 'created_at': self.created_at}
