@@ -15,7 +15,7 @@ class Project(AbstractApiClass):
         self.feature_groups_enabled = featureGroupsEnabled
 
     def __repr__(self):
-        return f"Project(project_id={repr(self.project_id)}, name={repr(self.name)}, use_case={repr(self.use_case)}, created_at={repr(self.created_at)}, feature_groups_enabled={repr(self.feature_groups_enabled)})"
+        return f"Project(project_id={repr(self.project_id)},\n  name={repr(self.name)},\n  use_case={repr(self.use_case)},\n  created_at={repr(self.created_at)},\n  feature_groups_enabled={repr(self.feature_groups_enabled)})"
 
     def to_dict(self):
         return {'project_id': self.project_id, 'name': self.name, 'use_case': self.use_case, 'created_at': self.created_at, 'feature_groups_enabled': self.feature_groups_enabled}
@@ -54,8 +54,8 @@ class Project(AbstractApiClass):
     def remove_column_mapping(self, dataset_id, column):
         return self.client.remove_column_mapping(self.project_id, dataset_id, column)
 
-    def list_feature_groups(self):
-        return self.client.list_project_feature_groups(self.project_id)
+    def list_feature_groups(self, filter_project_feature_group_type=None):
+        return self.client.list_project_feature_groups(self.project_id, filter_project_feature_group_type)
 
     def get_training_config_options(self):
         return self.client.get_training_config_options(self.project_id)
